@@ -2,11 +2,11 @@
 
 __author__ = """shimakaze-git"""
 __email__ = "shimakaze.soft+github@googlemail.com"
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 __copyright__ = "Copyright (C) 2020 shimakaze-git"
 __license__ = "MIT"
 __author_email__ = "shimakaze.soft+github@googlemail.com"
 __url__ = "http://github.com/shimakaze-git/django-jp-birthday"
 
-__all__ = ["fields", "managers", "models"]
+__all__ = ["fields", "managers", "models", "eras", "admin"]
