@@ -39,6 +39,7 @@ class BirthdayTestProcessSpeed(TestCase):
 
         jan1 = date(year=2010, month=1, day=1)
 
+        print("test_get_upcoming_birthdays")
         start = time.perf_counter()
         ModelTest.objects.get_upcoming_birthdays(30, jan1)
         end = time.perf_counter()
@@ -58,12 +59,13 @@ class BirthdayTestProcessSpeed(TestCase):
 
     def test_order_by_birthday(self):
 
+        print("test_order_by_birthday")
         start = time.perf_counter()
 
         years = [obj.birthday.year for obj in ModelTest.objects.order_by("birthday")]
+        end = time.perf_counter()
         birthdays = sorted([int(b.split("-")[0]) for b in self.birthdays])
 
-        end = time.perf_counter()
         run_time = end - start
         print("test_order_by_birthday 1", run_time)
 
